//+------------------------------------------------------------------+
//|                                          Close Trades Button.mq4 |
//|                                                    Keith Watford |
//|                                                                  |
//+------------------------------------------------------------------+
#property copyright "Keith Watford"
#property link      ""
#property version   "1.00"
#property strict
//--- input parameters
input int         Slippage=5;//Maximum Slippage Allowed in Pips
sinput string     s1;//****Button Inputs****
input int         Xco=5;//X C0_ordinate (Pixel distance from left)  
input int         Yco=30;//Y C0_ordinate (Pixel distance from top) 

input int         Width=200;
input int         Height=20;
input color       ButtonColor=clrAqua;//Button Color

int          Slip;
string       ButtonName="Close Trades Button";

#include <stdlib.mqh>
#include <stderror.mqh>
//+------------------------------------------------------------------+
//| Expert initialization function                                   |
//+------------------------------------------------------------------+
int OnInit()
  {
   if(Digits==5 || Digits==3)
     {
      Slip=Slippage*10;
     }

   string text="Close All "+_Symbol+" Trades";
   ButtonCreate(0,ButtonName,0,Xco,Yco,Width,Height,CORNER_LEFT_UPPER,text);
   ObjectSetInteger(0,ButtonName,OBJPROP_COLOR,clrBlack);
   ObjectSetInteger(0,ButtonName,OBJPROP_BGCOLOR,ButtonColor);
   ObjectSetInteger(0,ButtonName,OBJPROP_BORDER_COLOR,C'0x4c,0x4c,0x4c');
//---
   return(INIT_SUCCEEDED);
  }
//+------------------------------------------------------------------+
//| Expert deinitialization function                                 |
//+------------------------------------------------------------------+
void OnDeinit(const int reason)
  {
   ObjectDelete(0,ButtonName);
//---
  }
//+------------------------------------------------------------------+
//| Expert tick function                                             |
//+------------------------------------------------------------------+
void OnTick()
  {
  }
//+------------------------------------------------------------------+
//| ChartEvent function                                              |
//+------------------------------------------------------------------+
void OnChartEvent(const int id,
                  const long &lparam,
                  const double &dparam,
                  const string &sparam)
  {

   if(ObjectGetInteger(0,ButtonName,OBJPROP_STATE)==true)
     {
      for(int x=OrdersTotal()-1;x>=0;x--)
        {
         if(OrderSelect(x,SELECT_BY_POS) && OrderSymbol()==_Symbol)
           {
            if(OrderType()==OP_BUY || OrderType()==OP_SELL)
              {
               if(!OrderClose(OrderTicket(),OrderLots(),OrderClosePrice(),Slip,clrNONE))
                  Print(TimeCurrent()," Error with Closing Order #"+(string)OrderTicket()+ErrorDescription(GetLastError()));
              }
            else   //Delete Pending Orders
              {
               if(!OrderDelete(OrderTicket(),clrNONE))
                  Print(TimeCurrent()," Error with Closing Pending Order #"+(string)OrderTicket()+ErrorDescription(GetLastError()));
              }
           }
        }
      ObjectSetInteger(0,ButtonName,OBJPROP_STATE,false);
     }
  }
//+------------------------------------------------------------------+
//| Create the button                                                |
//+------------------------------------------------------------------+

bool ButtonCreate(const long              chart_ID=0,               // chart's ID
                  const string            name="Button",            // button name
                  const int               sub_window=0,             // subwindow index
                  const int               _x=0,                      // X coordinate
                  const int               _y=0,                      // Y coordinate
                  const int               _width=50,                 // button width
                  const int               _height=18,                // button height
                  const ENUM_BASE_CORNER  corner=CORNER_LEFT_UPPER, // chart corner for anchoring
                  const string            text="Button",            // text
                  const string            font="Arial",             // font
                  const int               font_size=11,             // font size
                  const color             clr=clrBlack,             // text color
                  const color             back_clr=C'236,233,216',  // background color
                  const color             border_clr=clrNONE,       // border color
                  const bool              state=false,              // pressed/released
                  const bool              back=false,               // in the background
                  const bool              selection=false,          // highlight to move
                  const bool              hidden=false,// hidden in the object list
                  const long              z_order=10) // priority for mouse click
  {
//--- reset the error value
   ResetLastError();
//--- create the button
   if(!ObjectCreate(chart_ID,name,OBJ_BUTTON,sub_window,0,0))
     {
      Print(__FUNCTION__,
            ": failed to create the button! Error code = ",GetLastError());
      return(false);
     }
//--- set button coordinates
   ObjectSetInteger(chart_ID,name,OBJPROP_XDISTANCE,_x);
   ObjectSetInteger(chart_ID,name,OBJPROP_YDISTANCE,_y);
//--- set button size
   ObjectSetInteger(chart_ID,name,OBJPROP_XSIZE,_width);
   ObjectSetInteger(chart_ID,name,OBJPROP_YSIZE,_height);
//--- set the chart's corner, relative to which point coordinates are defined
   ObjectSetInteger(chart_ID,name,OBJPROP_CORNER,corner);
//--- set the text
   ObjectSetString(chart_ID,name,OBJPROP_TEXT,text);
//--- set text font
   ObjectSetString(chart_ID,name,OBJPROP_FONT,font);
//--- set font size
   ObjectSetInteger(chart_ID,name,OBJPROP_FONTSIZE,font_size);
//--- set text color
   ObjectSetInteger(chart_ID,name,OBJPROP_COLOR,clr);
//--- set background color
   ObjectSetInteger(chart_ID,name,OBJPROP_BGCOLOR,back_clr);
//--- set border color
   ObjectSetInteger(chart_ID,name,OBJPROP_BORDER_COLOR,border_clr);
//--- display in the foreground (false) or background (true)
   ObjectSetInteger(chart_ID,name,OBJPROP_BACK,back);
//--- set button state
   ObjectSetInteger(chart_ID,name,OBJPROP_STATE,state);
//--- enable (true) or disable (false) the mode of moving the button by mouse
   ObjectSetInteger(chart_ID,name,OBJPROP_SELECTABLE,selection);
   ObjectSetInteger(chart_ID,name,OBJPROP_SELECTED,selection);
//--- hide (true) or display (false) graphical object name in the object list
   ObjectSetInteger(chart_ID,name,OBJPROP_HIDDEN,hidden);
//--- set the priority for receiving the event of a mouse click in the chart
   ObjectSetInteger(chart_ID,name,OBJPROP_ZORDER,z_order);
//--- successful execution
   return(true);
  }
//+------------------------------------------------------------------+
